@@ -31,4 +31,6 @@
  */
 
 extern char	*fsdevice;
+extern char	**cmdline;
+extern int	ncmdline;
 extern void	init(int argc, char **argv);
