@@ -129,6 +129,7 @@ typedef struct xfs_mount {
 	int			m_bsize;	/* fs logical block size */
 	xfs_agnumber_t		m_agfrotor;	/* last ag where space found */
 	xfs_agnumber_t		m_agirotor;	/* last ag dir inode alloced */
+	xfs_agnumber_t	m_maxagi;		/* highest inode alloc group */
 	uint			m_rsumlevels;	/* rt summary levels */
 	uint			m_rsumsize;	/* size of rt summary, bytes */
 	struct xfs_inode	*m_rbmip;	/* pointer to bitmap inode */
@@ -182,6 +183,7 @@ typedef struct xfs_mount {
 extern xfs_mount_t	*libxfs_mount (xfs_mount_t *, xfs_sb_t *,
 				dev_t, dev_t, dev_t, int);
 extern void	libxfs_mount_common (xfs_mount_t *, xfs_sb_t *);
+extern void	libxfs_initialize_perag (xfs_mount_t *, int);
 extern void	libxfs_umount (xfs_mount_t *);
 extern int	libxfs_rtmount_init (xfs_mount_t *);
 extern void	libxfs_alloc_compute_maxlevels (xfs_mount_t *);
@@ -332,6 +334,11 @@ typedef struct xfs_inode {
 	xfs_dinode_core_t	i_d;		/* most of ondisk inode */
 } xfs_inode_t;
 
+typedef struct {
+	uid_t	cr_uid;
+	gid_t	cr_gid;
+} cred_t;
+
 extern int	libxfs_inode_alloc (xfs_trans_t **, xfs_inode_t *, mode_t,
 				ushort, dev_t, cred_t *, xfs_inode_t **);
 extern void	libxfs_trans_inode_alloc_buf (xfs_trans_t *, xfs_buf_t *);
@@ -420,7 +427,7 @@ extern int	libxfs_alloc_fix_freelist (xfs_alloc_arg_t *, int);
 extern int	libxfs_alloc_file_space (xfs_inode_t *, xfs_off_t,
 				xfs_off_t, int, int);
 
-extern xfs_dahash_t	libxfs_da_hashname (char *, int);
+extern xfs_dahash_t	libxfs_da_hashname (uchar_t *, int);
 extern int	libxfs_attr_leaf_newentsize (xfs_da_args_t *, int, int *);
 
 extern xfs_filblks_t	libxfs_bmbt_get_blockcount (xfs_bmbt_rec_t *);
