@@ -39,6 +39,11 @@
 #include <sys/ioctl.h>
 #include <sys/mount.h>
 
+/* Until glibc catches up... */
+#ifndef BLKGETSIZE64
+#define BLKGETSIZE64 _IOR(0x12,114,sizeof(__uint64_t))
+#endif
+
 #define findrawpath(x)	x
 #define findblockpath(x) x
 
@@ -128,7 +133,7 @@ findsize(char *path)
 {
 	int	fd;
 	int	error;
-	unsigned long	size;
+	__uint64_t	size;
 	struct stat64	st;
 
 	/* Test to see if we are dealing with a regular file rather than a
@@ -150,10 +155,20 @@ findsize(char *path)
 			progname, path, strerror(errno));
 		exit(1);
 	}
-	error = ioctl(fd, BLKGETSIZE, &size);
-	if (error < 0) {
-		fprintf(stderr, "%s: can't determine device size\n", progname);
-		exit(1);
+	error = ioctl(fd, BLKGETSIZE64, &size);
+	if (error >= 0) {
+		/* BLKGETSIZE64 returns size in bytes not 512-byte blocks */
+		size = size >> 9;
+	} else {
+		/* If BLKGETSIZE64 fails, try BLKGETSIZE */
+		unsigned long tmpsize;
+		error = ioctl(fd, BLKGETSIZE, &tmpsize);
+		if (error < 0) {
+			fprintf(stderr, "%s: can't determine device size\n",
+				progname);
+			exit(1);
+		}
+		size = (__uint64_t)tmpsize;
 	}
 
 	close(fd);
@@ -205,16 +220,12 @@ libxfs_device_open(char *path, int creat, int readonly, int setblksize)
 			progname, path, strerror(errno));
 		exit(1);
 	}
-	
-#ifdef HAVE_BLKBSZSET
+
 	/*
-	 * Set device blocksize to 512 bytes
-	 *
-	 * See bug #801063, but we no longer have this ioctl in the kernel -
-	 * it will be needed again though when the fs blocksize != pagesize.
+	 * Set device blocksize to 512 bytes (see bug #801063)
 	 */
 #ifndef BLKBSZSET
-#define BLKBSZSET _IO(0x12,110)	/* set device block size */
+#define BLKBSZSET _IOW(0x12,113,sizeof(int))	/* set device block size */
 #endif
 	if (!readonly && setblksize && (statb.st_mode & S_IFMT) == S_IFBLK) {
 		int blocksize = 512; /* bytes */
@@ -224,11 +235,11 @@ libxfs_device_open(char *path, int creat, int readonly, int setblksize)
 				progname, path, strerror(errno));
 		}
 	}
-#endif
 
-	/* get the device number from the stat buf - unless
+	/*
+	 * Get the device number from the stat buf - unless
 	 * we're not opening a real device, in which case
-	 * choose a new fake device number
+	 * choose a new fake device number.
 	 */
 	dev=(statb.st_rdev)?(statb.st_rdev):(nextfakedev--);
 
@@ -634,6 +645,7 @@ rtmount_inodes(xfs_mount_t *mp)
 	return 0;
 }
 
+#define XFS_MOUNT_32BITINODES	0x1
 /*
  * Mount structure initialization, provides a filled-in xfs_mount_t
  * such that the numerous XFS_* macros can be used.  If dev is zero,
@@ -657,6 +669,7 @@ libxfs_mount(
 	mp->m_dev = dev;
 	mp->m_rtdev = rtdev;
 	mp->m_logdev = logdev;
+	mp->m_flags = XFS_MOUNT_32BITINODES;
 	mp->m_sb = *sb;
 	sbp = &(mp->m_sb);
 	manage_zones(0);
@@ -752,6 +765,8 @@ libxfs_mount(
 		exit(1);
 	}
 
+	libxfs_initialize_perag(mp, sbp->sb_agcount);
+
 	/*
 	 * mkfs calls mount before the root inode is allocated.
 	 */
