@@ -95,6 +95,7 @@
 #define xfs_dir2_bogus_removename	libxfs_dir2_bogus_removename
 
 #define xfs_mount_common                libxfs_mount_common
+#define xfs_initialize_perag            libxfs_initialize_perag
 #define xfs_rtmount_init                libxfs_rtmount_init
 #define xfs_alloc_fix_freelist		libxfs_alloc_fix_freelist
 #define xfs_iread			libxfs_iread
@@ -169,9 +170,8 @@
 #define xfs_buf_item_log_debug(bip,a,b)	((void) 0)	/* debug only */
 #define xfs_validate_extents(e,n,f)	((void) 0)	/* debug only */
 #define xfs_buf_relse(bp)		libxfs_putbuf(bp)
-#define xfs_read_buf(mp,x,blkno,len,f,bpp)	\
-	( *(bpp) = libxfs_readbuf( (mp)->m_dev, (blkno), (len), 1), 0 )
-
+#define xfs_read_buf(mp,devp,blkno,len,f,bpp)	\
+	( *(bpp) = libxfs_readbuf( *(dev_t*)devp, (blkno), (len), 1), 0 )
 
 /* transaction management */
 #define xfs_trans_set_sync(tp)			((void) 0)
@@ -184,7 +184,6 @@
 #define xfs_trans_unreserve_blkquota(tp,i,n)	((void) 0)
 #define xfs_trans_unreserve_rtblkquota(tp,i,n)	((void) 0)
 
-
 /* memory management */
 #define KM_SLEEP	1
 #define KM_SLEEP_IO	2
@@ -193,6 +192,7 @@
 #define kmem_zone_zalloc(z, f)	libxfs_zone_zalloc(z)
 #define kmem_zone_free(z, p)	libxfs_zone_free(z, p)
 #define kmem_realloc(p,sz,u,f)	libxfs_realloc(p,sz)
+#define kmem_zalloc(size, f)	libxfs_malloc(size)
 #define kmem_alloc(size, f)	libxfs_malloc(size)
 #define kmem_free(p, size)	libxfs_free(p)
 
@@ -207,7 +207,6 @@
 #define xfs_dir2_trace_args_sb(where, args, s, bp)	((void) 0)
 #define xfs_dir_shortform_validate_ondisk(a,b)		((void) 0)
 
-
 /* block management */
 #define xfs_bmap_check_extents(ip,w)			((void) 0)
 #define xfs_bmap_trace_delete(f,d,ip,i,c,w)		((void) 0)
@@ -226,8 +225,12 @@
 #define XFS_BMBT_TRACE_ARGIK(c,i,k)			((void) 0)
 #define XFS_BMBT_TRACE_CURSOR(c,s)			((void) 0)
 
+/* space allocation */
+#define xfs_alloc_search_busy(tp,ag,b,len)		((void) 0)
+#define xfs_alloc_mark_busy(tp,ag,b,len)		((void) 0)
 
 /* anything else */
+typedef __uint32_t uint_t;
 typedef __uint32_t inst_t;	/* an instruction */
 typedef enum { B_FALSE, B_TRUE } boolean_t;
 typedef struct { dev_t dev; } buftarg_t;
@@ -237,6 +240,7 @@ typedef struct { dev_t dev; } buftarg_t;
 #define EFSCORRUPTED	990	/* Filesystem is corrupted */
 #define ktrace_t	void
 #define m_ddev_targp	m_dev
+#define m_rtdev_targp(m)(&(m)->m_rtdev)
 #define KERN_WARNING
 #define XFS_ERROR(e)	(e)
 #define XFS_TEST_ERROR(expr,a,b,c)	( expr )
@@ -244,14 +248,16 @@ typedef struct { dev_t dev; } buftarg_t;
 #define TRACE_ALLOC(s,a)		((void) 0)
 #define TRACE_MODAGF(a,b,c)		((void) 0)
 #define XFS_FORCED_SHUTDOWN(mp)		0
-#define XFS_MOUNT_WSYNC			0
-#define XFS_MOUNT_NOALIGN		0
+#define XFS_MOUNT_WSYNC			0	/* ignored in userspace */
+#define XFS_MOUNT_NOALIGN		0	/* ignored in userspace */
+#define XFS_MOUNT_32BITINODES		0x1	/* enforce in userspace */
 #define XFS_ILOCK_EXCL			0
 #define mrlock(a,b,c)			((void) 0)
 #define mraccunlock(a)			((void) 0)
 #define mrunlock(a)			((void) 0)
 #define mraccess(a)			((void) 0)
 #define ismrlocked(a,b)			1
+#define spinlock_init(a,b)		((void) 0)
 #define ovbcopy(from,to,count)		memmove(to,from,count)
 #define __return_address		__builtin_return_address(0)
 #define xfs_btree_reada_bufl(m,fsb,c)	((void) 0)
@@ -275,7 +281,7 @@ typedef struct { dev_t dev; } buftarg_t;
 	__res; })
 
 #include <asm/page.h>
-#define NBPP	PAGE_SIZE
+#define NBPP		PAGE_SIZE
 
 static inline int atomicIncWithWrap(int *a, int b)
 {
@@ -369,9 +375,9 @@ int  xfs_iextents_copy (xfs_inode_t *, xfs_bmbt_rec_32_t *, int);
 int  xfs_iflush_int (xfs_inode_t *, xfs_buf_t *);
 int  xfs_iflush_fork (xfs_inode_t *, xfs_dinode_t *, xfs_inode_log_item_t *,
 		int, xfs_buf_t *);
-int  xfs_iformat_local (xfs_inode_t *, xfs_dinode_t *, int, int, int);
-int  xfs_iformat_extents (xfs_inode_t *, xfs_dinode_t *, int, int);
-int  xfs_iformat_btree (xfs_inode_t *, xfs_dinode_t *, int, int);
+int  xfs_iformat_local (xfs_inode_t *, xfs_dinode_t *, int, int);
+int  xfs_iformat_extents (xfs_inode_t *, xfs_dinode_t *, int);
+int  xfs_iformat_btree (xfs_inode_t *, xfs_dinode_t *, int);
 void xfs_iroot_realloc (xfs_inode_t *, int, int);
 void xfs_idata_realloc (xfs_inode_t *, int, int);
 void xfs_iext_realloc (xfs_inode_t *, int, int);
@@ -451,7 +457,7 @@ int  xfs_alloc_split (xfs_btree_cur_t *, int, xfs_agblock_t *,
 			xfs_alloc_key_t *, xfs_btree_cur_t **, int *);
 
 /* xfs_da_btree.c */
-xfs_dabuf_t *xfs_da_buf_make (int, xfs_buf_t **, inst_t *, int);
+xfs_dabuf_t *xfs_da_buf_make (int, xfs_buf_t **, inst_t *);
 int  xfs_da_root_join (xfs_da_state_t *, xfs_da_state_blk_t *);
 int  xfs_da_root_split (xfs_da_state_t *, xfs_da_state_blk_t *,
 			xfs_da_state_blk_t *);
