@@ -1551,7 +1551,7 @@ xfs_da_path_shift(xfs_da_state_t *state, xfs_da_state_path_t *path,
  * This is implemented with some source-level loop unrolling.
  */
 xfs_dahash_t
-xfs_da_hashname(char *name, int namelen)
+xfs_da_hashname(uchar_t *name, int namelen)
 {
 	xfs_dahash_t hash;
 
@@ -2013,7 +2013,6 @@ xfs_da_do_buf(
 	int		nbplist=0;
 	int		nfsb;
 	int		nmap;
-	int		mem_flags = trans ? KM_SLEEP : KM_SLEEP_IO;
 	xfs_dabuf_t	*rbp;
 
 	mp = dp->i_mount;
@@ -2051,7 +2050,7 @@ xfs_da_do_buf(
 			xfs_fsblock_t	firstblock;
 
 			firstblock = NULLFSBLOCK;
-			mapp = kmem_alloc(sizeof(*mapp) * nfsb, mem_flags);
+			mapp = kmem_alloc(sizeof(*mapp) * nfsb, KM_SLEEP);
 			nmap = nfsb;
 			if ((error = xfs_bmapi(trans, dp, (xfs_fileoff_t)bno,
 					nfsb,
@@ -2072,7 +2071,7 @@ xfs_da_do_buf(
 		goto exit0;
 	}
 	if (caller != 3 && nmap > 1) {
-		bplist = kmem_alloc(sizeof(*bplist) * nmap, mem_flags);
+		bplist = kmem_alloc(sizeof(*bplist) * nmap, KM_SLEEP);
 		nbplist = 0;
 	} else
 		bplist = NULL;
@@ -2132,9 +2131,9 @@ xfs_da_do_buf(
 	 * Build a dabuf structure.
 	 */
 	if (bplist) {
-		rbp = xfs_da_buf_make(nbplist, bplist, ra, mem_flags);
+		rbp = xfs_da_buf_make(nbplist, bplist, ra);
 	} else if (bp)
-		rbp = xfs_da_buf_make(1, &bp, ra, mem_flags);
+		rbp = xfs_da_buf_make(1, &bp, ra);
 	else
 		rbp = NULL;
 	/*
@@ -2144,18 +2143,21 @@ xfs_da_do_buf(
 		xfs_dir2_data_t		*data;
 		xfs_dir2_free_t		*free;
 		xfs_da_blkinfo_t	*info;
+		uint			magic, magic1;
 
 		info = rbp->data;
 		data = rbp->data;
 		free = rbp->data;
-		if (XFS_TEST_ERROR((INT_GET(info->magic, ARCH_CONVERT) != XFS_DA_NODE_MAGIC) &&
-				   (INT_GET(info->magic, ARCH_CONVERT) != XFS_DIR_LEAF_MAGIC) &&
-				   (INT_GET(info->magic, ARCH_CONVERT) != XFS_ATTR_LEAF_MAGIC) &&
-				   (INT_GET(info->magic, ARCH_CONVERT) != XFS_DIR2_LEAF1_MAGIC) &&
-				   (INT_GET(info->magic, ARCH_CONVERT) != XFS_DIR2_LEAFN_MAGIC) &&
-				   (INT_GET(data->hdr.magic, ARCH_CONVERT) != XFS_DIR2_BLOCK_MAGIC) &&
-				   (INT_GET(data->hdr.magic, ARCH_CONVERT) != XFS_DIR2_DATA_MAGIC) &&
-				   (INT_GET(free->hdr.magic, ARCH_CONVERT) != XFS_DIR2_FREE_MAGIC),
+		magic = INT_GET(info->magic, ARCH_CONVERT);
+		magic1 = INT_GET(data->hdr.magic, ARCH_CONVERT);
+		if (XFS_TEST_ERROR((magic != XFS_DA_NODE_MAGIC) &&
+				   (magic != XFS_DIR_LEAF_MAGIC) &&
+				   (magic != XFS_ATTR_LEAF_MAGIC) &&
+				   (magic != XFS_DIR2_LEAF1_MAGIC) &&
+				   (magic != XFS_DIR2_LEAFN_MAGIC) &&
+				   (magic1 != XFS_DIR2_BLOCK_MAGIC) &&
+				   (magic1 != XFS_DIR2_DATA_MAGIC) &&
+				   (magic1 != XFS_DIR2_FREE_MAGIC),
 				mp, XFS_ERRTAG_DA_READ_BUF,
 				XFS_RANDOM_DA_READ_BUF)) {
 			xfs_buftrace("DA READ ERROR", rbp->bps[0]);
@@ -2297,7 +2299,7 @@ lock_t		xfs_dabuf_global_lock;
  */
 /* ARGSUSED */
 STATIC xfs_dabuf_t *
-xfs_da_buf_make(int nbuf, xfs_buf_t **bps, inst_t *ra, int mem_flags)
+xfs_da_buf_make(int nbuf, xfs_buf_t **bps, inst_t *ra)
 {
 	xfs_buf_t		*bp;
 	xfs_dabuf_t	*dabuf;
@@ -2305,9 +2307,9 @@ xfs_da_buf_make(int nbuf, xfs_buf_t **bps, inst_t *ra, int mem_flags)
 	int		off;
 
 	if (nbuf == 1)
-		dabuf = kmem_zone_alloc(xfs_dabuf_zone, mem_flags);
+		dabuf = kmem_zone_alloc(xfs_dabuf_zone, KM_SLEEP);
 	else
-		dabuf = kmem_alloc(XFS_DA_BUF_SIZE(nbuf), mem_flags);
+		dabuf = kmem_alloc(XFS_DA_BUF_SIZE(nbuf), KM_SLEEP);
 	dabuf->dirty = 0;
 #ifdef XFS_DABUF_DEBUG
 	dabuf->ra = ra;
@@ -2335,7 +2337,7 @@ xfs_da_buf_make(int nbuf, xfs_buf_t **bps, inst_t *ra, int mem_flags)
 	}
 #ifdef XFS_DABUF_DEBUG
 	{
-		int		s;
+		SPLDECL(s);
 		xfs_dabuf_t	*p;
 
 		s = mutex_spinlock(&xfs_dabuf_global_lock);
@@ -2390,7 +2392,7 @@ xfs_da_buf_done(xfs_dabuf_t *dabuf)
 		kmem_free(dabuf->data, BBTOB(dabuf->bbcount));
 #ifdef XFS_DABUF_DEBUG
 	{
-		int	s;
+		SPLDECL(s);
 
 		s = mutex_spinlock(&xfs_dabuf_global_lock);
 		if (dabuf->prev)
